==> healthrian_visualization_support-1.0.16.tar.gz: lib/src/widgets/wear_cardio_t/connection_state_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'connection_state_weart.g.dart';

@CopyWith()
class ConnectionStateWearT extends StatelessWidget {
  const ConnectionStateWearT({
    super.key,
    this.width = 50,
    this.height = 50,
    this.onConnectedWidget,
    this.onDisconnectedWidget,
  });

  final double width;
  final double height;

  final Widget? onConnectedWidget;
  final Widget? onDisconnectedWidget;

  @override
  Widget build(BuildContext context) {
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: BLEManager().manageWearEcg12.streams.connectionStateStream,
          builder: (context, snapshot) {
            final connected = snapshot.data ?? false;
            return SizedBox(
              width: width,
              height: height,
              child: connected
                  ? (onConnectedWidget ??
                      Icon(
                        Icons.close,
                        size: min(width, height),
                      ))
                  : (onDisconnectedWidget ??
                      Icon(
                        Icons.check,
                        size: min(width, height),
                      )),
            );
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.0.36.tar.gz: lib/src/widgets/wear_cardio_t/connection_state_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'connection_state_weart.g.dart';

@CopyWith()
class ConnectionStateWearT extends StatelessWidget {
  const ConnectionStateWearT({
    super.key,
    this.width = 50,
    this.height = 50,
    this.onConnectedWidget,
    this.onDisconnectedWidget,
  });

  final double width;
  final double height;

  final Widget? onConnectedWidget;
  final Widget? onDisconnectedWidget;

  @override
  Widget build(BuildContext context) {
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: BLEManager().manageWearCardioT.streams.connectionStateStream,
          builder: (context, snapshot) {
            final connected = snapshot.data ?? false;
            return SizedBox(
              width: width,
              height: height,
              child: connected
                  ? (onConnectedWidget ??
                      Icon(
                        Icons.check,
                        size: min(width, height),
                      ))
                  : (onDisconnectedWidget ??
                      Icon(
                        Icons.close,
                        size: min(width, height),
                      )),
            );
          },
        );
      },
    );
  }
}
